@@ -1,23 +1,20 @@
-global iwlibs
-from pythonwifi import iwlibs
+### Author: Dag Wieers <dag@wieers.com>
 
 class dstat_plugin(dstat):
     def __init__(self):
         self.name = 'wifi'
+        self.nick = ('lnk', 's/n')
         self.type = 'd'
         self.width = 3
-        self.scale = 33
-        self.check()
-        self.vars = iwlibs.getNICnames()
-        self.nick = ('lnk', 's/n')
+        self.scale = 34
         self.cols = 2
 
-    def check(self): 
+    def check(self):
         global iwlibs
-        try:
-            from pythonwifi import iwlibs
-        except:
-            raise Exception, 'Needs python-wifi module'
+        from pythonwifi import iwlibs
+
+    def vars(self):
+        return iwlibs.getNICnames()
 
     def extract(self):
         for name in self.vars:
